<?php

class actionContentItemParse extends cmsAction {

    public function run(){

        $user = (object) array(
			'id' => 1,
			'is_admin' => 1,
			'is_logged' => 1,
			'groups' => array(0 => 6),
			'ip' => '127.0.0.1',
			'is_locked' => false,
			'lock_until' => false,
			'lock_reason' => false,
			'karma' => 100,
			'phone' => false,
			'perms' => array('news' => array('add' => 1)),
		);

        // Получаем название типа контента
        $ctype_name = $this->request->get('ctype_name', '');

        // Получаем тип контента
        $ctype = $this->model->getContentTypeByName($ctype_name);
        if (!$ctype) { cmsCore::error404(); }

		$item = array();

        if ($ctype['is_cats']){
            $category_id = $this->request->get('to_id', 0);
        }

        // Определяем наличие полей-свойств
        $props = $this->model->getContentProps($ctype['name']);
        $ctype['props'] = $props;

        // Если этот контент можно создавать в группах (сообществах) то получаем список групп
        $groups_list = array();

        // Если включены личные папки - получаем их список
        $folders_list = array();

        // Получаем поля для данного типа контента
        $this->model->orderBy('ordering');
        $fields = $this->model->getContentFields($ctype['name']);

        $form = $this->getItemForm($ctype, $fields, 'add', array(
            'groups_list' => $groups_list,
            'folders_list' => $folders_list
        ));

        $is_moderator = true;
        $is_premoderation = false;

		cmsEventsManager::hook("content_add", $ctype);
        list($form, $item) = cmsEventsManager::hook("content_{$ctype['name']}_form", array($form, $item));

        // Форма отправлена?
        $is_submitted = $this->request->has('submit');

        if (!$is_submitted && !empty($category_id)) { $item['category_id'] = $category_id; }

        $item['ctype_name'] = $ctype['name'];
		$item['ctype_id'] = $ctype['id'];

        if ($is_submitted){

            if ($ctype['props']){
                $props_cat_id = $this->request->get('category_id', 0);
                if ($props_cat_id){
                    $item_props = $this->model->getContentProps($ctype['name'], $props_cat_id);
                    $item_props_fields = $this->getPropsFields($item_props);
                    foreach($item_props_fields as $field){
                        $form->addField('props', $field);
                    }
                }
            }

            // Парсим форму и получаем поля записи
            $item = array_merge($item, $form->parse($this->request, $is_submitted));

            // Проверям правильность заполнения
            $errors = $form->validate($this,  $item);

			if (!$errors){
				list($item, $errors) = cmsEventsManager::hook('content_validate', array($item, $errors));
			} else {
				foreach($errors as $key => $error){
					$mess = $error . ' <b>' . $key . '</b> к новости "' . $item['title'] . '"';
					cmsUser::addSessionMessage($mess, 'error');
				}
			}

            if (!$errors){

                unset($item['ctype_name']);
                unset($item['ctype_id']);

                $item['is_approved'] = 1;

                $item['parent_type'] = null;
                $item['parent_title'] = null;
                $item['parent_url'] = null;
                $item['is_parent_hidden'] = null;

				$is_pub_control = true;
				$is_date_pub_allowed = false;
				$is_date_pub_end_allowed =false;
				$is_date_pub_days_allowed = false;
				$pub_max_days = false;

				$date_pub_time = isset($item['date_pub']) ? strtotime($item['date_pub']) : time();
				$now_time = time();
                $now_date = strtotime(date('Y-m-d', $now_time));
				$is_pub = true;
					
				$item['date_pub_end'] = false;

				unset($item['pub_days']);
				$item['is_pub'] = 1;

                $item = cmsEventsManager::hook("content_before_add", $item);
                $item = cmsEventsManager::hook("content_{$ctype['name']}_before_add", $item);
				
				$item['user_id'] = $user->id;
				
				// SEO параметры
				if (method_exists($this, 'prepareItemSeo')){
					$item_seo = $this->prepareItemSeo($item, $fields, $ctype);
					if(empty($ctype['options']['is_manual_title']) && !empty($ctype['options']['seo_title_pattern'])){
						$item['seo_title'] = string_replace_keys_values($ctype['options']['seo_title_pattern'], $item_seo);
					}
					if ($ctype['is_auto_keys']){
						if(!empty($ctype['options']['seo_keys_pattern'])){
							$item['seo_keys'] = string_replace_keys_values($ctype['options']['seo_keys_pattern'], $item_seo);
						} else {
							$item['seo_keys'] = string_get_meta_keywords($item['content']);
						}
					}
					if ($ctype['is_auto_desc']){
						if(!empty($ctype['options']['seo_desc_pattern'])){
							$item['seo_desc'] = string_get_meta_description(string_replace_keys_values($ctype['options']['seo_desc_pattern'], $item_seo));
						} else {
							$item['seo_desc'] = string_get_meta_description($item['content']);
						}
					}
                } else {
					if ($ctype['is_auto_keys']){ $item['seo_keys'] = string_get_meta_keywords($item['content']); }
					if ($ctype['is_auto_desc']){ $item['seo_desc'] = string_get_meta_description($item['content']); }
				}

                $item = $this->model->addContentItem($ctype, $item, $fields);

                cmsEventsManager::hook("content_after_add", $item);
                cmsEventsManager::hook("content_{$ctype['name']}_after_add", $item);

                if ($item['is_approved']){
                    cmsEventsManager::hook("content_after_add_approve", array('ctype_name'=>$ctype_name, 'item'=>$item));
                    cmsEventsManager::hook("content_{$ctype['name']}_after_add_approve", $item);
                }

                $back_url = $this->request->get('back', '');

                if ($back_url){
                    return false;
                }

            }

            if ($errors){
                cmsUser::addSessionMessage(LANG_FORM_ERRORS, 'error');
            }

        }

        return cmsTemplate::getInstance()->render('item_form', array(
            'do' => 'add',
            'parent' => isset($parent) ? $parent : false,
            'ctype' => $ctype,
            'item' => $item,
            'form' => $form,
            'props' => $props,
            'is_moderator' => $is_moderator,
            'is_premoderation' => $is_premoderation,
            'is_load_props' => !isset($errors),
            'add_cats' => isset($add_cats) ? $add_cats : array(),
            'errors' => isset($errors) ? $errors : false
        ));

    }

}
