<?php

class modelParsing extends cmsModel{
	
	public $options = array();
	public $default_cat = 6;
	
	public function __construct() {
        parent::__construct();
        $this->options = cmsController::loadOptions('parsing');
		$user = cmsUser::getInstance();
        $user->id = 1;
        $user->is_admin = 1;
        $user->is_logged = 1;
        $user->files_count = 60;
        $user->karma = 60;
        $user->groups = array(0 => 6);
    }

	public function getSources($id = false){
		$this->useCache("parsing.sources");
		return $id ? $this->getItemById('parsing_sources', $id) : $this->get('parsing_sources');
	}
	
	public function addSource($data){
		cmsCache::getInstance()->clean("parsing.sources");
		$this->insert('parsing_sources', $data);
	}

	public function updateSource($id, $data){
		cmsCache::getInstance()->clean("parsing.sources");
		$this->update('parsing_sources', $id, $data);
	}

	public function getFilters($id){
		$this->useCache("parsing.filters");
		$this->filterEqual('parent', $id)->filterOr()->filterEqual('parent', 'all');
		return $this->get('parsing_filters');
	}
	
	public function getFilterByTitle($title){
		$this->useCache("parsing.filters");
		return $this->getItemByField('parsing_filters', 'title', $title);
	}
	
	public function addFilter($data){
		cmsCache::getInstance()->clean("parsing.filters");
		$this->insert('parsing_filters', $data);
	}

	public function updateFilter($id, $data){
		cmsCache::getInstance()->clean("parsing.filters");
		$this->update('parsing_filters', $id, $data);
	}
	
	public function deleteFilter($id){
		cmsCache::getInstance()->clean("parsing.filters");
		$this->delete('parsing_filters', $id);
	}
	
	public function getSourceCats($id){
		$this->useCache("parsing.cats");
		return $id ? $this->getItemByField('parsing_cats', 'parent', $id, function($item, $model){
			$item['cats'] = cmsModel::yamlToArray($item['cats']);
			return $item;
		}) : false;
	}

	public function addSourceCats($data){
		cmsCache::getInstance()->clean("parsing.cats");
		$this->insert('parsing_cats', $data);
	}

	public function updateSourceCats($id, $data){
		cmsCache::getInstance()->clean("parsing.cats");
		$this->update('parsing_cats', $id, $data);
	}
	
	public function curl_get_contents($url, $post_data = false){
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_HEADER, 0);
		curl_setopt($ch, CURLOPT_REFERER, "http://google.com");
		curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.0.1) Gecko/2008070208');
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
		if($post_data){
			curl_setopt($ch, CURLOPT_POST, true);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $post_data);
		}
		$data = curl_exec($ch);
		curl_close($ch);
		return $data;
	}
	
	public function deleteController($id) {
		$this->db->dropTable('parsing_cats');
		$this->db->dropTable('parsing_filters');
		$this->db->dropTable('parsing_sources');
		$this->delete('scheduler_tasks', 'parsing', 'controller');
		return parent::deleteController($id);	 
	}
	
}
